# Vulnerability Disclosure

If you think you have found a potential security vulnerability,
please open a [draft Security Advisory](https://github.com/atlanhq/application-sdk/security/advisories/new) via GitHub. We will coordinate verification and next steps through that secure medium.

If English is not your first language, please try to describe the
problem and its impact to the best of your ability. For greater detail,
please use your native language and we will try our best to translate it
using online services.

Please also include the code you used to find the problem and the
shortest amount of code necessary to reproduce it.

Please do not disclose this to anyone else. We will retrieve a CVE
identifier if necessary and give you full credit under whatever name or
alias you provide. We will only request an identifier when we have a fix
and can publish it in a release.

We will respect your privacy and will only publicize your involvement if
you grant us permission.